@@ -1,4 +1,4 @@
-from cli.utils import auth_headers
+from cli.utils import fetch_auth
 from table_logger import TableLogger
 import requests
 import json
@@ -7,26 +7,28 @@ import logging
 log = logging.getLogger(__name__)
 
 
-def create_new_job(name, operation, config, datasets, url, token):
+@fetch_auth
+def create_new_job(name, operation, config, datasets, url, auth_headers):
     """ create job on ragnarok """
     endpoint = f'{url}/api/v1/jobs/'
     data = {
-        'operation': operation,
+        'operation': operation.upper(),
         'name': name,
         'input_data_sets': datasets,
         'config': json.dumps(config)
     }
-    r = requests.post(endpoint, data=data, headers=auth_headers(token))
+    r = requests.post(endpoint, data=data, headers=auth_headers)
     if r.status_code != 201:
         log.warning(f'Unable to create {operation} job {name} on datasets {datasets}')
         return
     log.info(f'created {operation} job {name} {config} on datasets {datasets}')
 
 
-def fetch_jobs(endpoint, token):
+@fetch_auth
+def fetch_jobs(url, auth_headers):
     """ fetch all datasets in ragnarok """
-    endpoint = f'{endpoint}/api/v1/jobs/'
-    r = requests.get(endpoint, headers=auth_headers(token))
+    endpoint = f'{url}/api/v1/jobs/'
+    r = requests.get(endpoint, headers=auth_headers)
     if r.status_code != 200:
         log.warning('Unable to fetch jobs')
         return
