@@ -1,4 +1,4 @@
-from cli.utils import auth_headers, download_url
+from cli.utils import fetch_auth, download_url
 from zpy.files import to_pathlib_path
 from table_logger import TableLogger
 import requests
@@ -9,23 +9,25 @@ import logging
 log = logging.getLogger(__name__)
 
 
-def create_scene(name, path, url, token):
+@fetch_auth
+def create_scene(name, path, url, auth_headers):
     """ upload a local scene to ragnarok """
     endpoint = f'{url}/api/v1/scenes/'
     data = {'name': name}
     files = {'file': open(path, 'rb')}
-    r = requests.post(endpoint, data=data, headers=auth_headers(token), files=files)
+    r = requests.post(endpoint, data=data, headers=auth_headers, files=files)
     if r.status_code != 201:
         log.warning(f'unable to create scene {name} from {path}')
         return
     log.info(f'created scene {name} from {path}')
 
 
-def fetch_scene(name, path, url, token):
+@fetch_auth
+def fetch_scene(name, path, url, auth_headers):
     """ fetch a scene from ragnarok """
     endpoint = f'{url}/api/v1/scenes/'
     params = {'name': name}
-    r = requests.get(endpoint, params=params, headers=auth_headers(token))
+    r = requests.get(endpoint, params=params, headers=auth_headers)
     if r.status_code != 200:
         log.warning(f'Unable to fetch scenes')
         return
@@ -35,7 +37,7 @@ def fetch_scene(name, path, url, token):
         return
     scene = response['results'][0]
     endpoint = f"{url}/api/v1/scenes/{scene['id']}/download"
-    r = requests.get(endpoint, headers=auth_headers(token))
+    r = requests.get(endpoint, headers=auth_headers)
     if r.status_code != 200:
         log.warning(f"Unable to get download link for scene {scene['id']}")
         return
@@ -45,10 +47,11 @@ def fetch_scene(name, path, url, token):
     download_url(response['redirect_link'], output_path)
 
 
-def fetch_scenes(endpoint, token):
+@fetch_auth
+def fetch_scenes(url, auth_headers):
     """ fetch all datasets in ragnarok """
-    endpoint = f'{endpoint}/api/v1/scenes/'
-    r = requests.get(endpoint, headers=auth_headers(token))
+    endpoint = f'{url}/api/v1/scenes/'
+    r = requests.get(endpoint, headers=auth_headers)
     if r.status_code != 200:
         log.warning('Unable to fetch scenes')
         return
