@@ -4,30 +4,41 @@
 import logging
 from pathlib import Path
 from pprint import pformat
-from typing import Any, Dict, Tuple
+from typing import Any, Dict, Tuple, Union
 
 import gin
 import zpy
 
 log = logging.getLogger(__name__)
 
-# HACK: Conversion from zpy keys to human-readable keys
-HUMAN_CONVERSION = {
-    'seed': 'zpy.blender.set_seed.seed',
-    'output_dir': 'zpy.saver.Saver.output_dir',
-    'output_path': 'zpy.saver.Saver.output_dir',
-    'num_images': 'zpy.blender.step.num_steps',
-    'num_frames': 'zpy.blender.step.num_steps',
-}
 
+def replace_human_redable_kwargs(
+    gin_bindings: Dict,
+    human_conversion: Dict = {
+        'seed': 'zpy.blender.set_seed.seed',
+        'output_dir': 'zpy.saver.Saver.output_dir',
+        'output_path': 'zpy.saver.Saver.output_dir',
+        'num_images': 'zpy.blender.step.num_steps',
+        'num_frames': 'zpy.blender.step.num_steps',
+    },
+) -> Tuple[str, Any]:
+    """[summary]
 
-def replace_human_redable_kwargs(gin_bindings: Dict) -> Tuple[str, Any]:
-    """ Replace any human readable versions of bindings. """
+    Args:
+        gin_bindings (Dict): Gin bindings dictionary {gin binding : value}.
+        human_conversion (Dict, optional): Conversion from zpy keys to human-readable keys.
+
+    Returns:
+        Tuple[str, Any]: A single gin bindings.
+
+    Yields:
+        Iterator[Tuple[str, Any]]: New gin bindings.
+    """
     log.info('Converting human readable bindings to gin...')
     for key, value in gin_bindings.items():
-        if HUMAN_CONVERSION.get(key, None) is not None:
-            log.info(f'Converted {key} to {HUMAN_CONVERSION[key]}')
-            yield HUMAN_CONVERSION[key], value
+        if human_conversion.get(key, None) is not None:
+            log.info(f'Converted {key} to {human_conversion[key]}')
+            yield human_conversion[key], value
         else:
             yield key, value
 
@@ -35,7 +46,11 @@ def replace_human_redable_kwargs(gin_bindings: Dict) -> Tuple[str, Any]:
 def parse_gin_bindings(
     gin_bindings: Dict = None,
 ) -> None:
-    """ Parse any extra gin bindings to the config. """
+    """ Parse any extra gin bindings to the config.
+
+    Args:
+        gin_bindings (Dict, optional): Gin bindings dictionary {gin binding : value}.
+    """
     if gin_bindings is None:
         log.info(f'No additional gin bindings to parse')
     else:
@@ -52,16 +67,24 @@ def parse_gin_bindings(
 
 def parse_gin_config(
     gin_config: str = None,
-    gin_config_dir: str = '$CONFIG',
+    gin_config_dir: Union[Path, str] = '$CONFIG',
 ) -> None:
-    """ Parse a gin config file by path. """
+    """ Parse a gin config file by path.
+
+    Args:
+        gin_config (str, optional): Name of gin config.
+        gin_config_dir (Union[Path, str], optional): Directory with gin configs.
+
+    Raises:
+        zpy.requests.InvalidRequest: Cannot find gin config at path.
+    """
     if gin_config is None:
         log.info(f'No gin file to parse.')
     else:
-        gin_config_dir = zpy.files.verify_path(gin_config_dir, check_dir=True)
         if not gin_config.endswith('.gin'):
             gin_config = gin_config + '.gin'
         gin_config_filename = Path(gin_config)
+        gin_config_dir = zpy.files.verify_path(gin_config_dir, check_dir=True)
         gin_config_path = gin_config_dir / gin_config_filename
         log.info(f'Parsing gin config at {gin_config_path}')
         if not gin_config_path.exists():
@@ -71,8 +94,14 @@ def parse_gin_config(
         gin.parse_config_file(str(gin_config_path))
 
 
-def parse_gin_in_request(request: Dict) -> None:
-    """ Parse any gin related keys in a request dict. """
+def parse_gin_in_request(
+    request: Dict,
+) -> None:
+    """ Parse any gin related keys in a request dict.
+
+    Args:
+        request (Dict): Request dictionary (see zpy.requests).
+    """
     zpy.gin.parse_gin_config(gin_config=request.get('gin_config', None))
     zpy.gin.parse_gin_bindings(gin_bindings=request.get('gin_bindings', None))
     gin.finalize()
