@@ -122,16 +122,6 @@ def make_aov_file_output_node(
     return fileout_node
 
 
-def lens_dirt_node(
-    node_tree: bpy.types.NodeTree,
-    input_node: bpy.types.Node,
-) -> bpy.types.Node:
-    """ Add lens dirt effect to a compositor node. """
-    # TODO: @kursad code to create dirt effect here.
-    log.warn("NotImplemented: lens dirt ")
-    return input_node
-
-
 def hsv_node(
     node_tree: bpy.types.NodeTree,
     input_node: bpy.types.Node,
@@ -142,6 +132,15 @@ def hsv_node(
     return hsv_node
 
 
+def lens_dirt_node(
+    node_tree: bpy.types.NodeTree,
+    input_node: bpy.types.Node,
+) -> bpy.types.Node:
+    """ TODO: Add lens dirt effect to a compositor node. """
+    log.warn("NotImplemented: lens dirt ")
+    return input_node
+
+
 @gin.configurable
 def render_aov(
     rgb_path: Union[Path, str] = None,
@@ -262,14 +261,16 @@ def _mute_aov_file_output_node(style: str, mute: bool = True):
 def default_render_settings(
     samples: int = 96,
     tile_size: int = 48,
-    spatial_splits: bool = False
+    spatial_splits: bool = False,
+    is_aggressive: bool = False
 ) -> None:
     """ Render settings for normal color images. 
-    
+
     Args:
         samples (int, optional): Number of Cycles samples per frame
         tile_size (int, optional): Rendering tile size in pixel dimensions
         spatial_splits (bool, optional): Toogle for BVH split acceleration
+        is_aggressive (bool, optional): Toogles aggressive render time reduction settings
     """
     scene = zpy.blender.verify_blender_scene()
     # Make sure engine is set to Cycles
@@ -281,7 +282,7 @@ def default_render_settings(
     scene.cycles.use_adaptive_sampling = True
     scene.cycles.use_denoising = False
     scene.cycles.denoiser = 'OPENIMAGEDENOISE'
-    
+
     scene.render.film_transparent = False
     scene.render.dither_intensity = 1.0
     scene.render.filter_size = 1.5
@@ -314,12 +315,13 @@ def default_render_settings(
     scene.cycles.debug_use_spatial_splits = spatial_splits
     scene.render.use_persistent_data = True
 
-    # Agressive settings
-    # render.use_simplify = True
-    # scene.cycles.ao_bounces_render = 1
-    # scene.world.light_settings.use_ambient_occlusion = True
-    # scene.world.light_settings.distance = 40
-    # scene.world.light_settings.ao_factor = 0.5
+    if is_aggressive:
+        scene.render.use_simplify = True
+        scene.cycles.ao_bounces_render = 1
+        scene.world.light_settings.use_ambient_occlusion = True
+        scene.world.light_settings.distance = 40
+        scene.world.light_settings.ao_factor = 0.5
+
 
 def segmentation_render_settings():
     """ Render settings for segmentation images. """
